.. _api:

API Reference
=============

Classes
-------

.. module:: authorizeme

.. autoclass:: Authorization
    :members:

.. autoclass:: AuthorizationError
    
.. autoclass:: PermissionError

.. autoclass:: RuleError
